@@ -13,8 +13,13 @@ def equal(x, y, almost=False, epsilon=1e-7):
                 % (type(x), type(y)))
 
 
-def aeq(*args, almost=False, epsilon=1e-7, msg=None):
-    assert len(args) > 1, "aeq a single element is meaningless"
+def aeq(*args, almost=False, epsilon=1e-7, msg=None, ignore_single=False):
+    if ignore_single and len(args) == 1:
+        return args[0]
+
+    assert len(args) > 1, (
+        "aeq a single element is meaningless (ignore with `ignore_single`")
+
     if msg is not None:
         msg = "[%s] " % msg
     else:
@@ -30,13 +35,17 @@ def aeq(*args, almost=False, epsilon=1e-7, msg=None):
     )
     return args[0]
 
-def aaeq(*args, almost=False, epsilon=1e-7, msg=None):
+def aaeq(*args, almost=False, epsilon=1e-7, msg=None, ignore_single=False):
+    if ignore_single and len(args) == 1:
+        return args[0]
+
     assert len(args) > 1, "aaeq a single element is meaningless, use aeq"
     if msg is not None:
         msg = "[%s] " % msg
     else:
         msg = ""
 
+    aeq(*[len(_) for _ in args], msg="Size mismatch")
     for i, args_i in enumerate(zip(*args)):
         assert all([
             equal(_,
@@ -45,8 +54,8 @@ def aaeq(*args, almost=False, epsilon=1e-7, msg=None):
                   epsilon=epsilon)
             for _ in args_i[1:]]
         ), (
-            "%sArguments are not all equal for element %d, %s."
-            % (msgi, str(args_i))
+            "%sArguments are not all equal at position %d, %s."
+            % (msg, i, str(args_i))
         )
     return args[0]
 
